==> pf4-component-mapper-3.21.2.tgz: package/esm/field-array/field-array.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["remove"],
    _excluded2 = ["remove"],
    _excluded3 = ["arrayValidator", "label", "description", "fields", "defaultItem", "meta", "minItems", "maxItems", "noItemsMessage", "buttonLabels"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { memo } from 'react';
import isEqual from 'lodash/isEqual';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArray from "@data-driven-forms/react-form-renderer/field-array";
import { Bullseye } from "@patternfly/react-core/dist/dynamic/layouts/Bullseye";
import { Button } from "@patternfly/react-core/dist/dynamic/components/Button";
import { Flex } from "@patternfly/react-core/dist/dynamic/layouts/Flex";
import { FlexItem } from "@patternfly/react-core/dist/dynamic/layouts/Flex";
import { FormFieldGroup } from "@patternfly/react-core/dist/dynamic/components/Form";
import { FormFieldGroupHeader } from "@patternfly/react-core/dist/dynamic/components/Form";
import { FormHelperText } from "@patternfly/react-core/dist/dynamic/components/Form";
import { Grid } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import { GridItem } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import TrashIcon from "@patternfly/react-icons/dist/dynamic/icons/trash-icon";
import './final-form-array.css';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";

var Spacer = function Spacer() {
  return /*#__PURE__*/React.createElement("span", {
    className: "ddf-final-form-spacer"
  });
};

var ArrayItem = /*#__PURE__*/memo(function (_ref) {
  var fields = _ref.fields,
      fieldIndex = _ref.fieldIndex,
      name = _ref.name,
      remove = _ref.remove,
      length = _ref.length,
      minItems = _ref.minItems,
      buttonLabels = _ref.buttonLabels,
      isLast = _ref.isLast;

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var editedFields = fields.map(function (field, index) {
    var computedName = field.name ? "".concat(name, ".").concat(field.name) : name;
    return _objectSpread(_objectSpread({}, field), {}, {
      name: computedName,
      key: "".concat(name, "-").concat(index)
    });
  });
  var isRemoveDisabled = length <= minItems;
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Flex, null, /*#__PURE__*/React.createElement(FlexItem, {
    className: "pf-c-form",
    grow: {
      "default": 'flex_1'
    }
  }, editedFields.map(function (field) {
    return renderForm([field]);
  })), /*#__PURE__*/React.createElement(FlexItem, null, editedFields[0].label && /*#__PURE__*/React.createElement(Spacer, null), /*#__PURE__*/React.createElement(Button, _extends({
    variant: "plain",
    "aria-label": buttonLabels.remove,
    disabled: isRemoveDisabled
  }, !isRemoveDisabled && {
    onClick: function onClick() {
      return remove(fieldIndex);
    }
  }), /*#__PURE__*/React.createElement(TrashIcon, null)))), !isLast && editedFields.length > 1 && /*#__PURE__*/React.createElement("hr", {
    className: "ddf-final-form-hr"
  }));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, _excluded);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, _excluded2);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  name: PropTypes.string,
  fieldIndex: PropTypes.number.isRequired,
  fields: PropTypes.arrayOf(PropTypes.object),
  remove: PropTypes.func.isRequired,
  length: PropTypes.number,
  minItems: PropTypes.number,
  buttonLabels: PropTypes.shape({
    remove: PropTypes.node
  }),
  isLast: PropTypes.bool
};

var DynamicArray = function DynamicArray(_ref4) {
  var props = _extends({}, _ref4);

  var _useFieldApi = useFieldApi(props),
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      formFields = _useFieldApi.fields,
      defaultItem = _useFieldApi.defaultItem,
      meta = _useFieldApi.meta,
      minItems = _useFieldApi.minItems,
      maxItems = _useFieldApi.maxItems,
      noItemsMessage = _useFieldApi.noItemsMessage,
      buttonLabels = _useFieldApi.buttonLabels,
      rest = _objectWithoutProperties(_useFieldApi, _excluded3);

  var dirty = meta.dirty,
      submitFailed = meta.submitFailed,
      error = meta.error,
      submitError = meta.submitError;
  var isError = (dirty || submitFailed) && (error || submitError) && (typeof error === 'string' || typeof submitError === 'string');

  var combinedButtonLabels = _objectSpread({
    add: 'Add item',
    removeAll: 'Delete all',
    remove: 'Remove'
  }, buttonLabels);

  return /*#__PURE__*/React.createElement(FieldArray, {
    key: rest.input.name,
    name: rest.input.name,
    validate: arrayValidator
  }, function (_ref5) {
    var _ref5$fields = _ref5.fields,
        map = _ref5$fields.map,
        _ref5$fields$value = _ref5$fields.value,
        value = _ref5$fields$value === void 0 ? [] : _ref5$fields$value,
        push = _ref5$fields.push,
        remove = _ref5$fields.remove,
        removeBatch = _ref5$fields.removeBatch;
    return /*#__PURE__*/React.createElement(FormFieldGroup, {
      header: /*#__PURE__*/React.createElement(FormFieldGroupHeader, {
        titleText: {
          text: label,
          id: props.name
        },
        titleDescription: description,
        actions: /*#__PURE__*/React.createElement(React.Fragment, null, minItems === 0 && /*#__PURE__*/React.createElement(Button, _extends({
          variant: "link",
          isDisabled: value.length === 0
        }, value.length !== 0 && {
          onClick: function onClick() {
            return removeBatch(value.map(function (_, index) {
              return index;
            }));
          }
        }), combinedButtonLabels.removeAll), /*#__PURE__*/React.createElement(Button, _extends({
          variant: "secondary",
          isDisabled: value.length >= maxItems
        }, !(value.length >= maxItems) && {
          onClick: function onClick() {
            return push(defaultItem);
          }
        }), combinedButtonLabels.add))
      })
    }, value.length <= 0 && /*#__PURE__*/React.createElement(Bullseye, null, noItemsMessage), map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        key: "".concat(name, "-").concat(index),
        fields: formFields,
        name: name,
        fieldIndex: index,
        remove: remove,
        length: value.length,
        minItems: minItems,
        buttonLabels: combinedButtonLabels,
        isLast: value.length === index + 1
      });
    }), /*#__PURE__*/React.createElement(Grid, null, /*#__PURE__*/React.createElement(GridItem, {
      sm: 11
    }, isError && /*#__PURE__*/React.createElement(FormHelperText, {
      isHidden: false,
      isError: true
    }, error || submitError))));
  });
};

DynamicArray.propTypes = {
  name: PropTypes.string,
  label: PropTypes.node,
  description: PropTypes.node,
  fields: PropTypes.arrayOf(PropTypes.object).isRequired,
  defaultItem: PropTypes.any,
  minItems: PropTypes.number,
  maxItems: PropTypes.number,
  noItemsMessage: PropTypes.node,
  buttonLabels: PropTypes.shape({
    add: PropTypes.node,
    remove: PropTypes.node,
    removeAll: PropTypes.node
  })
};
DynamicArray.defaultProps = {
  maxItems: Infinity,
  minItems: 0,
  noItemsMessage: 'No items added'
};
export default DynamicArray;

==> pf4-component-mapper-3.23.0.tgz: package/esm/field-array/field-array.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["remove"],
    _excluded2 = ["remove"],
    _excluded3 = ["arrayValidator", "label", "description", "fields", "defaultItem", "meta", "minItems", "maxItems", "noItemsMessage", "buttonLabels"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { memo } from 'react';
import isEqual from 'lodash/isEqual';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArray from "@data-driven-forms/react-form-renderer/field-array";
import { Bullseye } from "@patternfly/react-core/dist/dynamic/layouts/Bullseye";
import { Button } from "@patternfly/react-core/dist/dynamic/components/Button";
import { Flex } from "@patternfly/react-core/dist/dynamic/layouts/Flex";
import { FlexItem } from "@patternfly/react-core/dist/dynamic/layouts/Flex";
import { FormFieldGroup } from "@patternfly/react-core/dist/dynamic/components/Form";
import { FormFieldGroupHeader } from "@patternfly/react-core/dist/dynamic/components/Form";
import { FormHelperText } from "@patternfly/react-core/dist/dynamic/components/Form";
import { Grid } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import { GridItem } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import TrashIcon from "@patternfly/react-icons/dist/dynamic/icons/trash-icon";
import './final-form-array.css';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";

var Spacer = function Spacer() {
  return /*#__PURE__*/React.createElement("span", {
    className: "ddf-final-form-spacer"
  });
};

var ArrayItem = /*#__PURE__*/memo(function (_ref) {
  var fields = _ref.fields,
      fieldIndex = _ref.fieldIndex,
      name = _ref.name,
      remove = _ref.remove,
      length = _ref.length,
      minItems = _ref.minItems,
      buttonLabels = _ref.buttonLabels,
      isLast = _ref.isLast;

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var editedFields = fields.map(function (field, index) {
    var computedName = field.name ? "".concat(name, ".").concat(field.name) : name;
    return _objectSpread(_objectSpread({}, field), {}, {
      name: computedName,
      key: "".concat(name, "-").concat(index)
    });
  });
  var isRemoveDisabled = length <= minItems;
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Flex, null, /*#__PURE__*/React.createElement(FlexItem, {
    className: "pf-c-form",
    grow: {
      "default": 'flex_1'
    }
  }, editedFields.map(function (field) {
    return renderForm([field]);
  })), /*#__PURE__*/React.createElement(FlexItem, null, editedFields[0].label && /*#__PURE__*/React.createElement(Spacer, null), /*#__PURE__*/React.createElement(Button, _extends({
    variant: "plain",
    "aria-label": buttonLabels.remove,
    disabled: isRemoveDisabled
  }, !isRemoveDisabled && {
    onClick: function onClick() {
      return remove(fieldIndex);
    }
  }), /*#__PURE__*/React.createElement(TrashIcon, null)))), !isLast && editedFields.length > 1 && /*#__PURE__*/React.createElement("hr", {
    className: "ddf-final-form-hr"
  }));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, _excluded);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, _excluded2);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  name: PropTypes.string,
  fieldIndex: PropTypes.number.isRequired,
  fields: PropTypes.arrayOf(PropTypes.object),
  remove: PropTypes.func.isRequired,
  length: PropTypes.number,
  minItems: PropTypes.number,
  buttonLabels: PropTypes.shape({
    remove: PropTypes.node
  }),
  isLast: PropTypes.bool
};

var DynamicArray = function DynamicArray(_ref4) {
  var props = _extends({}, _ref4);

  var _useFieldApi = useFieldApi(props),
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      formFields = _useFieldApi.fields,
      defaultItem = _useFieldApi.defaultItem,
      meta = _useFieldApi.meta,
      _useFieldApi$minItems = _useFieldApi.minItems,
      minItems = _useFieldApi$minItems === void 0 ? 0 : _useFieldApi$minItems,
      _useFieldApi$maxItems = _useFieldApi.maxItems,
      maxItems = _useFieldApi$maxItems === void 0 ? Infinity : _useFieldApi$maxItems,
      _useFieldApi$noItemsM = _useFieldApi.noItemsMessage,
      noItemsMessage = _useFieldApi$noItemsM === void 0 ? 'No items added' : _useFieldApi$noItemsM,
      buttonLabels = _useFieldApi.buttonLabels,
      rest = _objectWithoutProperties(_useFieldApi, _excluded3);

  var dirty = meta.dirty,
      submitFailed = meta.submitFailed,
      error = meta.error,
      submitError = meta.submitError;
  var isError = (dirty || submitFailed) && (error || submitError) && (typeof error === 'string' || typeof submitError === 'string');

  var combinedButtonLabels = _objectSpread({
    add: 'Add item',
    removeAll: 'Delete all',
    remove: 'Remove'
  }, buttonLabels);

  return /*#__PURE__*/React.createElement(FieldArray, {
    key: rest.input.name,
    name: rest.input.name,
    validate: arrayValidator
  }, function (_ref5) {
    var _ref5$fields = _ref5.fields,
        map = _ref5$fields.map,
        _ref5$fields$value = _ref5$fields.value,
        value = _ref5$fields$value === void 0 ? [] : _ref5$fields$value,
        push = _ref5$fields.push,
        remove = _ref5$fields.remove,
        removeBatch = _ref5$fields.removeBatch;
    return /*#__PURE__*/React.createElement(FormFieldGroup, {
      header: /*#__PURE__*/React.createElement(FormFieldGroupHeader, {
        titleText: {
          text: label,
          id: props.name
        },
        titleDescription: description,
        actions: /*#__PURE__*/React.createElement(React.Fragment, null, minItems === 0 && /*#__PURE__*/React.createElement(Button, _extends({
          variant: "link",
          isDisabled: value.length === 0
        }, value.length !== 0 && {
          onClick: function onClick() {
            return removeBatch(value.map(function (_, index) {
              return index;
            }));
          }
        }), combinedButtonLabels.removeAll), /*#__PURE__*/React.createElement(Button, _extends({
          variant: "secondary",
          isDisabled: value.length >= maxItems
        }, !(value.length >= maxItems) && {
          onClick: function onClick() {
            return push(defaultItem);
          }
        }), combinedButtonLabels.add))
      })
    }, value.length <= 0 && /*#__PURE__*/React.createElement(Bullseye, null, noItemsMessage), map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        key: "".concat(name, "-").concat(index),
        fields: formFields,
        name: name,
        fieldIndex: index,
        remove: remove,
        length: value.length,
        minItems: minItems,
        buttonLabels: combinedButtonLabels,
        isLast: value.length === index + 1
      });
    }), /*#__PURE__*/React.createElement(Grid, null, /*#__PURE__*/React.createElement(GridItem, {
      sm: 11
    }, isError && /*#__PURE__*/React.createElement(FormHelperText, {
      isHidden: false,
      isError: true
    }, error || submitError))));
  });
};

DynamicArray.propTypes = {
  name: PropTypes.string,
  label: PropTypes.node,
  description: PropTypes.node,
  fields: PropTypes.arrayOf(PropTypes.object).isRequired,
  defaultItem: PropTypes.any,
  minItems: PropTypes.number,
  maxItems: PropTypes.number,
  noItemsMessage: PropTypes.node,
  buttonLabels: PropTypes.shape({
    add: PropTypes.node,
    remove: PropTypes.node,
    removeAll: PropTypes.node
  })
};
export default DynamicArray;
